@@ -27,7 +27,7 @@ import sys
 import codecs
 sys.stdout = codecs.getwriter('utf8')(sys.stdout)
 
-__VERSION__ = '0.3.5'
+__VERSION__ = '0.3.6'
 
 DESCRIPTION = 'Bumpversion: v{} (using Python v{})'.format(
     __VERSION__,
@@ -92,7 +92,7 @@ class Git(object):
 
     @classmethod
     def add_path(cls, path):
-        subprocess.check_call(["git", "add", path])
+        subprocess.check_call(["git", "add", "--update", path])
 
     @classmethod
     def commit(cls, message):
@@ -334,7 +334,7 @@ def main(args=None):
 
     taggroup = parser3.add_mutually_exclusive_group()
 
-    taggroup.add_argument('--tag', action='store_true', dest="tag", default=defaults.get("commit", False),
+    taggroup.add_argument('--tag', action='store_true', dest="tag", default=defaults.get("tag", False),
                           help='Create a tag in version control')
     taggroup.add_argument('--no-tag', action='store_false', dest="tag",
                           help='Do not create a tag in version control', default=argparse.SUPPRESS)
